local gr		= love.graphics
local monitor	= { watch = {},font	= gr.newFont( 16 ) }
local clr		= {
	background	= { 155, 155, 155, 210 },
	border		= {   0,  55, 155 },
	text		= { 255, 255,   0 }}
local sx, sy	= love.window.getDimensions( )

function monitor.watchBox(  wd, x, y, title )
	local savefont=gr.getFont()
	gr.setFont(monitor.font)
	local title		= title or 'Monitored Items'
	local w			= wd or 200
	local minwidth	= gr.getFont():getWidth( title ) + 38
	local w			= w > minwidth and w or minwidth
	local fontsize	= gr.getFont():getHeight()
	local fontbase	= gr.getFont():getBaseline( )
	local fonthigh	= gr.getFont():getHeight()
	local size		= 0
	for i, _ in pairs( monitor.watch ) do size = size + 1 end
	if fontbase + size * fonthigh + 25 > 500 then
		start		= size - math.floor( ( 500 - fontbase ) / fonthigh )
		else start	= 1
		end
	local h			= fontbase+( size - start + 1 ) * fonthigh + 25
	local x			= ( x or sx/2 ) - w/2
	local y			= ( y or sy/2 ) - h/2
	gr.setColor( clr.background )
	monitor.roundedRectangle( 'fill', x, y, w, h, 8, 8 )			-- box
	gr.setColor( clr.border )
	monitor.roundedRectangle( 'line', x + 5, y + 5, w - 10, h - 10, 8, 8 )	-- box border
	monitor.roundedRectangle( 'line', x + 5, y + 5, w - 10, 20, 8, 8 )	-- title box
	gr.circle( 'line', x + w - 16, y + 15, 7 )							-- upper-right
	gr.setColor( clr.text )
	gr.print( title, x + 10, y + 14 - fontbase/2 )
	local count = 0
	for i, v in pairs( monitor.watch ) do
		count = count + 1
		if count >= start then
			gr.print( i..' = '..v, x + 10, y + fontbase-(count-size+1)*fonthigh + fontbase+20 )
			end
		end
	gr.setFont( savefont )		-- reset font to calling script's font
	end

function monitor.roundedRectangle( mode, x, y, w, h, rx, ry )
	assert( mode=='fill' or mode=='line', 'mode must equal "fill" or "line"')
	ry = ry or rx
	local pts = {}
	local precision = math.floor( 0.2 * ( rx + ry ) )
	local  hP =  math.pi / 2
	rx = rx >= w / 2 and w / 2 - 1   or rx
	ry = ry >= h / 2 and h / 2 - 1   or ry
	local sin, cos = math.sin, math.cos
	for i = 0, precision do					-- upper right
		local a = ( i / precision - 1 ) * hP
		pts[#pts+1] = x + w - rx * ( 1 -  cos(a) )
		pts[#pts+1] = y + ry * ( 1 +  sin(a) )
		end
	for i = 2 * precision + 2 , 1, -2 do	-- lower right
		pts[#pts+1] = pts[i-1]
		pts[#pts+1] = 2 * y - pts[i] + h
		end
	for i = 1, 2 * precision + 2,  2 do		-- lower left
		pts[#pts+1] = -pts[i] + 2 * x + w
		pts[#pts+1] = 2 * y - pts[i+1] + h
		end
	for i = 2 * precision + 2 , 1, -2 do	-- upper left
		pts[#pts+1]	= -pts[i-1] + 2 * x + w
		pts[#pts+1]	= pts[i]
		end
	gr.polygon( mode, pts )
	end

return monitor
